==> haskell-network-protocol-xmpp-0.4.10-22-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-network-protocol-xmpp.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 network-protocol-xmpp
version:              0.4.10
visibility:           public
id:                   network-protocol-xmpp-0.4.10-8jfppKVWBO9A475myEjaw4
key:                  network-protocol-xmpp-0.4.10-8jfppKVWBO9A475myEjaw4
license:              GPL-3.0-only
maintainer:           Stephen Paul Weber <singpolyma@singpolyma.net>
author:
    John Millikin <jmillikin@gmail.com>, Stephan Maka <stephan@spaceboyz.net>

stability:            experimental
homepage:             https://git.sr.ht/~singpolyma/network-protocol-xmpp
synopsis:             Client library for the XMPP protocol.
category:             Network
abi:                  fd24341e9efcdb34ea9c4261e6580937
exposed:              True
exposed-modules:      Network.Protocol.XMPP Network.Protocol.XMPP.Internal
hidden-modules:
    Network.Protocol.XMPP.Client
    Network.Protocol.XMPP.Client.Authentication
    Network.Protocol.XMPP.Client.Features
    Network.Protocol.XMPP.Component Network.Protocol.XMPP.Connections
    Network.Protocol.XMPP.ErrorT Network.Protocol.XMPP.Handle
    Network.Protocol.XMPP.JID Network.Protocol.XMPP.Monad
    Network.Protocol.XMPP.Stanza Network.Protocol.XMPP.XML
    Network.Protocol.XMPP.String

import-dirs:          /usr/lib/ghc-9.0.2/site-local/network-protocol-xmpp-0.4.10
library-dirs:         /usr/lib/ghc-9.0.2/site-local/network-protocol-xmpp-0.4.10
dynamic-library-dirs: /usr/lib
data-dir:
    /usr/share/x86_64-linux-ghc-9.0.2/network-protocol-xmpp-0.4.10

hs-libraries:         HSnetwork-protocol-xmpp-0.4.10-8jfppKVWBO9A475myEjaw4
depends:
    base-4.15.1.0 bytestring-0.10.12.1
    gnuidn-0.2.2-9ET5SrAMmESI4V14cyTjHe
    gnutls-0.2-BqAtU0crXMtD7K2qKBMR6f
    gsasl-0.3.7-FYY5np9HZnOF5YRxWLAq6n
    libxml-sax-0.7.5-LHQZjHtnpgS3xRGlDiwwnx
    monads-tf-0.1.0.3-LS0v3a5UuzO9oiSqbetO8t
    network-3.1.2.7-3FYESTraHEuFjogiXBqfxS
    network-simple-0.4.5-5ge9HbPzyOc6bjdwZLuWRG text-1.2.5.0
    transformers-0.5.6.2 xml-types-0.3.8-5QCBKSWiifmEtQB2jlqHYu

haddock-interfaces:
    /usr/share/doc/haskell-network-protocol-xmpp/html/network-protocol-xmpp.haddock

haddock-html:         /usr/share/doc/haskell-network-protocol-xmpp/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-network-protocol-xmpp-0.4.10-26-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-network-protocol-xmpp.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 network-protocol-xmpp
version:              0.4.10
visibility:           public
id:                   network-protocol-xmpp-0.4.10-AnR3RN93fnHMDjIFAYlTf
key:                  network-protocol-xmpp-0.4.10-AnR3RN93fnHMDjIFAYlTf
license:              GPL-3.0-only
maintainer:           Stephen Paul Weber <singpolyma@singpolyma.net>
author:
    John Millikin <jmillikin@gmail.com>, Stephan Maka <stephan@spaceboyz.net>

stability:            experimental
homepage:             https://git.sr.ht/~singpolyma/network-protocol-xmpp
synopsis:             Client library for the XMPP protocol.
category:             Network
abi:                  12ba7d008096481e2c25b4acc27edd08
exposed:              True
exposed-modules:      Network.Protocol.XMPP Network.Protocol.XMPP.Internal
hidden-modules:
    Network.Protocol.XMPP.Client
    Network.Protocol.XMPP.Client.Authentication
    Network.Protocol.XMPP.Client.Features
    Network.Protocol.XMPP.Component Network.Protocol.XMPP.Connections
    Network.Protocol.XMPP.ErrorT Network.Protocol.XMPP.Handle
    Network.Protocol.XMPP.JID Network.Protocol.XMPP.Monad
    Network.Protocol.XMPP.Stanza Network.Protocol.XMPP.XML
    Network.Protocol.XMPP.String

import-dirs:          /usr/lib/ghc-9.0.2/site-local/network-protocol-xmpp-0.4.10
library-dirs:         /usr/lib/ghc-9.0.2/site-local/network-protocol-xmpp-0.4.10
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-network-protocol-xmpp
hs-libraries:         HSnetwork-protocol-xmpp-0.4.10-AnR3RN93fnHMDjIFAYlTf
depends:
    base-4.15.1.0 bytestring-0.10.12.1
    gnuidn-0.2.2-9ET5SrAMmESI4V14cyTjHe
    gnutls-0.2-BqAtU0crXMtD7K2qKBMR6f
    gsasl-0.3.7-FYY5np9HZnOF5YRxWLAq6n
    libxml-sax-0.7.5-LHQZjHtnpgS3xRGlDiwwnx
    monads-tf-0.1.0.3-LS0v3a5UuzO9oiSqbetO8t
    network-3.1.2.7-3BOR0Zygkx81QadwHjCIWF
    network-simple-0.4.5-61CB8qkroGn4HuHRaPdx8b text-1.2.5.0
    transformers-0.5.6.2 xml-types-0.3.8-5QCBKSWiifmEtQB2jlqHYu

haddock-interfaces:
    /usr/share/doc/haskell-network-protocol-xmpp/html/network-protocol-xmpp.haddock

haddock-html:         /usr/share/doc/haskell-network-protocol-xmpp/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
